CheckError

Enum CheckError 

pub enum CheckError {
    IntraDocLink(String),
    File(PathBuf),
    Http(Url),
    HttpForbidden(Url),
    Fragment(Link, String, Option<Vec<String>>),
    Io(Box<IoError>),
}

Variants

An intra-doc link went unresolved by rustdoc and ended up in the final HTML



File(PathBuf)

A relatively linked file did not exist



Http(Url)

A linked HTTP URL did not exist



HttpForbidden(Url)

An HTTP URL was encountered, but HTTP checking was forbidden



Fragment(Link, String, Option<Vec<String>>)

The linked file existed, but was missing the linked HTML anchor



Io(Box<IoError>)

An error occured while trying to find whether the file or URL existed